# -*- coding: utf-8 -*-
"""
Created on Tue Nov 19 12:59:34 2024

@author: mstep
"""

import pygame
def draw_image(surface, image, position, alignment):
    '''Draw the image on the surface with the indicated alignment.'''
    # See where we should draw it.
    if alignment == 'nw':
        rect = image.get_rect(topleft=position)
    elif alignment == 'n':
        rect = image.get_rect(midtop=position)
    elif alignment == 'ne':
        rect = image.get_rect(topright=position)
    elif alignment == 'w':
        rect = image.get_rect(midleft=position)
    elif alignment == 'c':
        rect = image.get_rect(center=position)
    elif alignment == 'e':
        rect = image.get_rect(midright=position)
    elif alignment == 'sw':
        rect = image.get_rect(bottomleft=position)
    elif alignment == 's':
        rect = image.get_rect(midbottom=position)
    elif alignment == 'se':
        rect = image.get_rect(bottomright=position)
    else:
        raise ValueError(f'Unknown draw_image alignment {alignment}')

    # Draw the image onto the surface in the rectangle.
    surface.blit(image, rect)

#%%

import pygame

class TextSprite:
    '''Sprite to display text.'''
    def __init__(self, text, position, alignment, font, color,
                 antialias=False, background=None):
        '''Prepare the text surface.'''
        # Validate the alignment.
        if alignment not in 'nw,n,ne,e,se,s,sw,w,c':
            raise ValueError(f'Unknown TextSprite alignment {alignment}')

        # Save the positioning parameters.
        self.position = position
        self.alignment = alignment

        # Draw the text onto its own surface.
        self.surface = font.render(text, antialias, color, background)

    def update(self, elapsed_seconds, bounds):
        pass

    def draw(self, surface):
        '''Draw the text.'''
        draw_image(surface, self.surface, self.position, self.alignment)

#%%

import pygame
import math

class CircleSprite:
    '''Sprite to display a circle.'''
    def __init__(self, center, radius, fill_color, outline_color):
        '''Save the drawing properties.'''
        self.center = center
        self.radius = radius
        self.fill_color = fill_color
        self.outline_color = outline_color

    def update(self, elapsed_seconds, bounds):
        pass

    def draw(self, surface):
        '''Draw the circle.'''
        pygame.draw.circle(surface, self.fill_color, self.center, self.radius)
        pygame.draw.circle(surface, self.outline_color, self.center,
                           self.radius, width=1)

#%%
import pygame
import pygame.locals
import random
import pygame.time

class TextApp:
    def __init__(self, game_name, screen_size, max_fps, bg_color):
        # Save game parameters.
        self.game_name = game_name
        self.screen_size = screen_size
        self.max_fps = max_fps
        self.bg_color = bg_color

        # Initialize pygame.
        pygame.init()
        pygame.display.set_caption(f'{self.game_name}')
        self.surface = pygame.display.set_mode(self.screen_size)
        self.bounds = self.surface.get_rect()

        # Make initial sprites.
        self.make_sprites()

        # Start the event loop.
        self.event_loop()

    def make_sprites(self):
        '''Make the sprites.'''
        self.all_sprites = []

        # Set rectangle size.
        margin = 20
        wid = (self.bounds.width - 4 * margin) / 3
        hgt = (self.bounds.height - 4 * margin) / 3

        # Set drawing parameters.
        font = pygame.font.SysFont('Calibri', 30)
        text_color = pygame.Color('black')
        fill_color = pygame.Color('light blue')
        outline_color = pygame.Color('blue')
        radius = 5

        # Make sprites.
        # NW
        rect = pygame.Rect(margin, margin, wid, hgt)
        position = rect.topleft
        self.all_sprites.insert(0,
            TextSprite('Northwest', position, 'nw',
                       font, text_color, True, pygame.Color('pink')))
        self.all_sprites.append(
            CircleSprite(position, radius, fill_color, outline_color))

        # N
        rect = rect.move(margin + wid, 0)
        position = rect.midtop
        self.all_sprites.insert(0,
            TextSprite('North', position, 'n',
                       font, text_color, True, pygame.Color('pink')))
        self.all_sprites.append(
            CircleSprite(position, radius, fill_color, outline_color))

        # NE
        rect = rect.move(margin + wid, 0)
        position = rect.topright
        self.all_sprites.insert(0,
            TextSprite('Northeast', position, 'ne',
                       font, text_color, True, pygame.Color('pink')))
        self.all_sprites.append(
            CircleSprite(position, radius, fill_color, outline_color))

        # W
        rect = pygame.Rect(margin, 2 * margin + hgt, wid, hgt)
        position = rect.midleft
        self.all_sprites.insert(0,
            TextSprite('West', position, 'w',
                       font, text_color, True, pygame.Color('pink')))
        self.all_sprites.append(
            CircleSprite(position, radius, fill_color, outline_color))

        # C
        rect = rect.move(margin + wid, 0)
        position = rect.center
        self.all_sprites.insert(0,
            TextSprite('Center', position, 'c',
                       font, text_color, True, pygame.Color('pink')))
        self.all_sprites.append(
            CircleSprite(position, radius, fill_color, outline_color))

        # E
        rect = rect.move(margin + wid, 0)
        position = rect.midright
        self.all_sprites.insert(0,
            TextSprite('East', position, 'e',
                       font, text_color, True, pygame.Color('pink')))
        self.all_sprites.append(
            CircleSprite(position, radius, fill_color, outline_color))

        # SW
        rect = pygame.Rect(margin, 3 * margin + 2 * hgt, wid, hgt)
        position = rect.bottomleft
        self.all_sprites.insert(0,
            TextSprite('Southwest', position, 'sw',
                       font, text_color, True, pygame.Color('pink')))
        self.all_sprites.append(
            CircleSprite(position, radius, fill_color, outline_color))

        # S
        rect = rect.move(margin + wid, 0)
        position = rect.midbottom
        self.all_sprites.insert(0,
            TextSprite('South', position, 's',
                       font, text_color, True, pygame.Color('pink')))
        self.all_sprites.append(
            CircleSprite(position, radius, fill_color, outline_color))

        # SE
        rect = rect.move(margin + wid, 0)
        position = rect.bottomright
        self.all_sprites.insert(0,
            TextSprite('Southeast', position, 'se',
                       font, text_color, True, pygame.Color('pink')))
        self.all_sprites.append(
            CircleSprite(position, radius, fill_color, outline_color))

    # Process events.
    def event_loop(self):
        clock = pygame.time.Clock()
        running = True
        while running:
            # Event loop.
            for event in pygame.event.get():
                # Quit.
                if event.type == pygame.locals.QUIT:
                    running = False
                    break

            # See how much time has passed since the last update.
            elapsed_ticks = clock.tick(self.max_fps)
            elapsed_seconds = elapsed_ticks / 1000

            # Update the sprites.
            self.update_sprites(elapsed_seconds)

            # Draw the sprites.
            self.draw_sprites()

            # Update the display.
            pygame.display.update()

        # End the program.
        pygame.display.quit()
        pygame.quit()

    def update_sprites(self, elapsed_seconds):
        '''Let the sprites update themselves.'''
        for sprite in self.all_sprites:
            sprite.update(elapsed_seconds, self.bounds)

    # Draw the sprites.
    def draw_sprites(self):
        self.surface.fill(self.bg_color)
        for sprite in self.all_sprites:
            sprite.draw(self.surface)


# Main program.
app = TextApp('pygame_text', screen_size=(400, 300), max_fps=30,
              bg_color=pygame.Color('light yellow'))

#    def __init__(self, game_name, screen_size, max_fps, bg_color):

print('Done')
